==> mmcv-1.2.6.tar.gz: mmcv-1.2.6/mmcv/image/__init__.py <==
# Copyright (c) Open-MMLab. All rights reserved.
from .colorspace import (bgr2gray, bgr2hls, bgr2hsv, bgr2rgb, bgr2ycbcr,
                         gray2bgr, gray2rgb, hls2bgr, hsv2bgr, imconvert,
                         rgb2bgr, rgb2gray, rgb2ycbcr, ycbcr2bgr, ycbcr2rgb)
from .geometric import (imcrop, imflip, imflip_, impad, impad_to_multiple,
                        imrescale, imresize, imresize_like, imrotate, imshear,
                        imtranslate, rescale_size)
from .io import imfrombytes, imread, imwrite, supported_backends, use_backend
from .misc import tensor2imgs
from .photometric import (adjust_brightness, adjust_color, adjust_contrast,
                          clahe, imdenormalize, imequalize, iminvert,
                          imnormalize, imnormalize_, lut_transform, posterize,
                          solarize)

__all__ = [
    'bgr2gray', 'bgr2hls', 'bgr2hsv', 'bgr2rgb', 'gray2bgr', 'gray2rgb',
    'hls2bgr', 'hsv2bgr', 'imconvert', 'rgb2bgr', 'rgb2gray', 'imrescale',
    'imresize', 'imresize_like', 'rescale_size', 'imcrop', 'imflip', 'imflip_',
    'impad', 'impad_to_multiple', 'imrotate', 'imfrombytes', 'imread',
    'imwrite', 'supported_backends', 'use_backend', 'imdenormalize',
    'imnormalize', 'imnormalize_', 'iminvert', 'posterize', 'solarize',
    'rgb2ycbcr', 'bgr2ycbcr', 'ycbcr2rgb', 'ycbcr2bgr', 'tensor2imgs',
    'imshear', 'imtranslate', 'adjust_color', 'imequalize',
    'adjust_brightness', 'adjust_contrast', 'lut_transform', 'clahe'
]

==> mmcv-1.3.5.tar.gz: mmcv-1.3.5/mmcv/image/__init__.py <==
# Copyright (c) Open-MMLab. All rights reserved.
from .colorspace import (bgr2gray, bgr2hls, bgr2hsv, bgr2rgb, bgr2ycbcr,
                         gray2bgr, gray2rgb, hls2bgr, hsv2bgr, imconvert,
                         rgb2bgr, rgb2gray, rgb2ycbcr, ycbcr2bgr, ycbcr2rgb)
from .geometric import (cutout, imcrop, imflip, imflip_, impad,
                        impad_to_multiple, imrescale, imresize, imresize_like,
                        imrotate, imshear, imtranslate, rescale_size)
from .io import imfrombytes, imread, imwrite, supported_backends, use_backend
from .misc import tensor2imgs
from .photometric import (adjust_brightness, adjust_color, adjust_contrast,
                          adjust_lighting, adjust_sharpness, auto_contrast,
                          clahe, imdenormalize, imequalize, iminvert,
                          imnormalize, imnormalize_, lut_transform, posterize,
                          solarize)

__all__ = [
    'bgr2gray', 'bgr2hls', 'bgr2hsv', 'bgr2rgb', 'gray2bgr', 'gray2rgb',
    'hls2bgr', 'hsv2bgr', 'imconvert', 'rgb2bgr', 'rgb2gray', 'imrescale',
    'imresize', 'imresize_like', 'rescale_size', 'imcrop', 'imflip', 'imflip_',
    'impad', 'impad_to_multiple', 'imrotate', 'imfrombytes', 'imread',
    'imwrite', 'supported_backends', 'use_backend', 'imdenormalize',
    'imnormalize', 'imnormalize_', 'iminvert', 'posterize', 'solarize',
    'rgb2ycbcr', 'bgr2ycbcr', 'ycbcr2rgb', 'ycbcr2bgr', 'tensor2imgs',
    'imshear', 'imtranslate', 'adjust_color', 'imequalize',
    'adjust_brightness', 'adjust_contrast', 'lut_transform', 'clahe',
    'adjust_sharpness', 'auto_contrast', 'cutout', 'adjust_lighting'
]
